@@ -3,7 +3,7 @@ package Wikibase::Datatype::Print;
 use strict;
 use warnings;
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 1;
 
@@ -43,7 +43,7 @@ TODO
 
 =item L<Wikibase::Datatype::Print::MediainfoSnak>
 
-TODO
+Wikibase mediainfo snak pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Property>
 
@@ -63,11 +63,11 @@ Wikibase sitelink pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Snak>
 
-TODO
+Wikibase snak pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Statement>
 
-TODO
+Wikibase statement pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Utils>
 
@@ -143,6 +143,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
